timespantools.timespan_2_overlaps_only_start_of_timespan_1
==========================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_overlaps_only_start_of_timespan_1.timespan_2_overlaps_only_start_of_timespan_1
